==> haskell-cryptohash-cryptoapi-0.1.4-27-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-cryptoapi
version: 0.1.4
id: cryptohash-cryptoapi-0.1.4-KiMOrZpCyufr9Zs7KH7Bl
key: cryptohash-cryptoapi-0.1.4-KiMOrZpCyufr9Zs7KH7Bl
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis: Crypto-api interfaces for cryptohash
description:
    Crypto-api interfaces for cryptohash
category: Cryptography
abi: 43500c741d4743d5fc549df41ed4865b
exposed: True
exposed-modules:
    Crypto.Hash.CryptoAPI
import-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-cryptoapi-0.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cryptohash-cryptoapi-0.1.4
hs-libraries: HScryptohash-cryptoapi-0.1.4-KiMOrZpCyufr9Zs7KH7Bl
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x
    cryptonite-0.25-Kkz1nviDHAZ2DrHW1oTQmX
    memory-0.14.18-9akydHRk1ZP1zabNg9e0SJ
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x=b38ee8fa4c1e132a024035423192fcff
             cryptonite-0.25-Kkz1nviDHAZ2DrHW1oTQmX=8ad4bf2e2634bfabb074533558bcba79
             memory-0.14.18-9akydHRk1ZP1zabNg9e0SJ=97b23ab1fbbf628d0139298474539e03
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
haddock-interfaces: /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-cryptoapi-0.1.4-32-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-cryptoapi
version: 0.1.4
id: cryptohash-cryptoapi-0.1.4-CUL803frvgF6IhVhPVu0qU
key: cryptohash-cryptoapi-0.1.4-CUL803frvgF6IhVhPVu0qU
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis: Crypto-api interfaces for cryptohash
description:
    Crypto-api interfaces for cryptohash
category: Cryptography
abi: 62561e099c9d4408e87b6a763ecaf0a3
exposed: True
exposed-modules:
    Crypto.Hash.CryptoAPI
import-dirs: /usr/lib/ghc-8.6.1/site-local/cryptohash-cryptoapi-0.1.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/cryptohash-cryptoapi-0.1.4
hs-libraries: HScryptohash-cryptoapi-0.1.4-CUL803frvgF6IhVhPVu0qU
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cereal-0.5.7.0-2uER3Agem8P6aYfM1x47n8
    crypto-api-0.13.3-43rwgg6didD9Ww3YkDbwy5
    cryptonite-0.25-G72X72CTowDHXdsNScvcPv
    memory-0.14.18-7DMShoecVUC5dB7z3aQ1xS
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB
haddock-interfaces: /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
